# generated by datamodel-codegen:
#   filename:  property/create_property_list_response.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import ConfigDict, Field

from ..core import ext as ext_1
from . import property_list


class CreatePropertyListResponse(AdCPBaseModel):
    model_config = ConfigDict(
        extra='forbid',
    )
    auth_token: Annotated[
        str,
        Field(
            description='Token that can be shared with sellers to authorize fetching this list. Store this - it is only returned at creation time.'
        ),
    ]
    ext: ext_1.ExtensionObject | None = None
    list: Annotated[property_list.PropertyList, Field(description='The created property list')]
